==> alwaysai-2.3.4.tgz: package/src/infrastructure/urls.ts <==
import { CliTerseError } from '@alwaysai/alwayscli';
import { getSystemId } from './system-id';

export function getRestURL() {
  let restUrl = '';
  switch (getSystemId()) {
    case 'local':
    case 'development':
      restUrl = 'https://lhm86739h4.execute-api.us-west-2.amazonaws.com/dev';
      break;
    case 'qa':
      restUrl = 'https://2fz3afqai8.execute-api.us-west-2.amazonaws.com/qa';
      break;
    case 'production':
      restUrl = 'https://uzirdisrmf.execute-api.us-west-2.amazonaws.com/prod';
      break;
    default:
      restUrl = 'https://uzirdisrmf.execute-api.us-west-2.amazonaws.com/prod';
      break;
  }
  return restUrl;
}

export const getRemoteDeploymentURL = () => {
  let remoteDeploymentUrl = '';
  switch (getSystemId()) {
    case 'local':
    case 'development':
      remoteDeploymentUrl = 'https://d2hamqrgv8.execute-api.us-west-2.amazonaws.com/dev';
      break;
    case 'qa':
      remoteDeploymentUrl = 'https://o5c3hg01t6.execute-api.us-west-2.amazonaws.com/qa';
      break;
    case 'production':
      remoteDeploymentUrl = 'https://wnsrjz93ce.execute-api.us-west-2.amazonaws.com/prod';
      break;
    default:
      throw new CliTerseError(`Remote deployment not supported on ${getSystemId()}!`);
  }
  return remoteDeploymentUrl;
};

export const getBaseURL = () => {
  let baseUrl = '';
  switch (getSystemId()) {
    case 'local':
      baseUrl = 'http://localhost:3000';
    case 'development':
      baseUrl = 'https://dashboard.a6i0.net';
      break;
    case 'qa':
      baseUrl = 'https://dashboard.a6i1.net';
      break;
    case 'production':
      baseUrl = 'https://www.alwaysai.co';
      break;
    default:
      baseUrl = 'https://www.alwaysai.co';
      break;
  }
  return baseUrl;
};

const envDomainMap = {
  development: 'a6i0.net',
  qa: 'a6i1.net',
  production: 'alwaysai.co',
};

export const serviceEndpointBuilder = (service: string, path: string): string => {
  const domain = envDomainMap[getSystemId()] || envDomainMap['production'];
  return `https://${service}.${domain}/${path}`;
};

==> alwaysai-2.5.1.tgz: package/src/infrastructure/urls.ts <==
import { CliTerseError } from '@alwaysai/alwayscli';
import { getSystemId } from './system-id';

export function getRestURL() {
  let restUrl = '';
  switch (getSystemId()) {
    case 'local':
    case 'development':
      restUrl = 'https://lhm86739h4.execute-api.us-west-2.amazonaws.com/dev';
      break;
    case 'qa':
      restUrl = 'https://2fz3afqai8.execute-api.us-west-2.amazonaws.com/qa';
      break;
    case 'production':
      restUrl = 'https://uzirdisrmf.execute-api.us-west-2.amazonaws.com/prod';
      break;
    default:
      restUrl = 'https://uzirdisrmf.execute-api.us-west-2.amazonaws.com/prod';
      break;
  }
  return restUrl;
}

export const getRemoteDeploymentURL = () => {
  let remoteDeploymentUrl = '';
  switch (getSystemId()) {
    case 'local':
    case 'development':
      remoteDeploymentUrl =
        'https://d2hamqrgv8.execute-api.us-west-2.amazonaws.com/dev';
      break;
    case 'qa':
      remoteDeploymentUrl =
        'https://o5c3hg01t6.execute-api.us-west-2.amazonaws.com/qa';
      break;
    case 'production':
      remoteDeploymentUrl =
        'https://wnsrjz93ce.execute-api.us-west-2.amazonaws.com/prod';
      break;
    default:
      throw new CliTerseError(
        `Remote deployment not supported on ${getSystemId()}!`
      );
  }
  return remoteDeploymentUrl;
};

export const getBaseURL = () => {
  let baseUrl = '';
  switch (getSystemId()) {
    case 'local':
      baseUrl = 'http://localhost:3000';
      break;
    case 'development':
      baseUrl = 'https://dashboard.a6i0.net';
      break;
    case 'qa':
      baseUrl = 'https://dashboard.a6i1.net';
      break;
    case 'production':
      baseUrl = 'https://www.alwaysai.co';
      break;
    default:
      baseUrl = 'https://www.alwaysai.co';
      break;
  }
  return baseUrl;
};

const envDomainMap = {
  development: 'a6i0.net',
  qa: 'a6i1.net',
  production: 'alwaysai.co'
};

export const serviceEndpointBuilder = (
  service: string,
  path: string
): string => {
  const domain = envDomainMap[getSystemId()] || envDomainMap['production'];
  return `https://${service}.${domain}/${path}`;
};
